@@ -1,4 +1,4 @@
-use crate::interface::{Sequence, SequenceMut};
+use crate::interface::{CloneableSequence, Sequence, SequenceMut};
 
 impl<'a, Item: 'a> Sequence<'a, Item, [Item]> for [Item] {
     type Iterator = std::slice::Iter<'a, Item>;
@@ -19,6 +19,8 @@ impl<'a, Item: 'a> SequenceMut<'a, Item, [Item]> for [Item] {
     }
 }
 
+impl<'a, Item: 'a + Clone> CloneableSequence<'a, Item, [Item]> for [Item] {}
+
 #[cfg(test)]
 mod tests {
     use crate::interface::Sequence;
@@ -28,6 +30,6 @@ mod tests {
         let array = [0, 1, 2];
         let slice = &array[0..2];
         // Making sure that the fully qualified syntax in the trait implementation works as I think and does not create endless recursion.
-        assert_eq!(2, Sequence::len(slice));
+        debug_assert_eq!(2, Sequence::len(slice));
     }
 }
